..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

========================
Code reviews with Gerrit
========================

Zaqar uses the `Gerrit`_ tool to review proposed code changes. The review site
is https://review.opendev.org.

Gerrit is a complete replacement for GitHub pull requests. `All GitHub pull
requests to the Zaqar repository will be ignored`.

See `Development Workflow with Gerrit`_ for more detailed documentation on how
to work with Gerrit.

.. _Gerrit: https://www.gerritcodereview.com/
.. _Development Workflow with Gerrit: https://docs.openstack.org/infra/manual/developers.html#development-workflow
